[<img src="https://unpackai.github.io/unpackai_logo.svg" alt="unpackAI Logo" width="500"/>](https://unpackai.com/)

**unpackAI Library - The library to ease your learning, building and the deployment of state-of-the-art deep learning models to empower your business and career.**

[![PyPI version](https://img.shields.io/pypi/v/unpackai)](https://pypi.org/project/unpackai/)
![Python version](https://img.shields.io/pypi/pyversions/unpackai)
![License](https://img.shields.io/github/license/unpackai/unpackai)
![PyPI Downloads](https://img.shields.io/pypi/dm/unpackai)
[![Bugs](https://img.shields.io/github/issues/unpackai/unpackai/bug)](https://github.com/unpackai/unpackai/issues?q=is%3Aissue+is%3Aopen+-label%3A"enhancement")
[![Enhancements](https://img.shields.io/github/issues/unpackai/unpackai/enhancement)](https://github.com/unpackai/unpackai/issues?q=is%3Aissue+is%3Aopen+label%3A"enhancement")
[![codecov](https://codecov.io/gh/unpackAI/unpackai/branch/main/graph/badge.svg)](https://codecov.io/gh/unpackAI/unpackai)

## Who is unpackAI?

unpackAI has the mission to make AI education as accessible as possible. Alongside our AI & Machine Learning Bootcamps for Business Professionals, we build this library to remove technical barriers and provide the right tools for individuals and businesses to allow for effective learning, building and deployment of AI projects. Find more information via our [website](https://unpackai.com/) and get in touch!

🌌 All applications - Build powerful applications in computer vision, natural language processing and tabular data.

⏱️ Save time - Don't waste time and utilize our end-to-end implementation process to build a model in hours.

🌩️ Learn & Build - Join our Bootcamps to easily master our entry friendly, repeatable and inuitive way to build state-of-the-art deep learning models whereever YOU need it.

## Installation

You can install this library with pip

```shell
pip install unpackai
```

or with github link to get the latest version

```shell
pip install git+https://github.com/unpackai/unpackai/
```

## Content

This package provides utilities for:

* Computer Vision (CV)
* Tabular Data
* Natural Language Processing (NLP)

## Documentation

Documentation is available [here](https://unpackai.github.io/unpackai).
